@@ -30,9 +30,9 @@ BASE_PROMPT = """You have an instance `env` with methods:
 - `env.find_element(by='id', value=None)` is like `env.find_elements()` but only returns the first element.
 - `env.find_nearest(e, xpath)` can be used to locate a GPTWebElement that matches the xpath near GPTWebElement e. 
 - `env.send_keys(element, text)` sends `text` to element. Be mindful of special keys, like "enter" (use Keys.ENTER) and "tab" (use Keys.TAB).
-- `env.click(element)` clicks the GPTWebElement.
+- `env.click(element)` clicks the GPTWebElement. Use this instead of `element.click()`.
 - `env.wait(seconds)` waits for `seconds`.
-- `env.scroll(direction, iframe=None)` scrolls the page. Will switch to `iframe` if given. `direction` can be "up", "down", "left", or "right". 
+- `env.scroll(direction, iframe=None)` scrolls. Switches to `iframe` if given. `direction` can be "up", "down", "left", or "right". 
 - `env.get_llm_response(text)` asks AI about a string `text`.
 - `env.retrieve_information(prompt, entire_page=False)` returns a string, information from a page given a prompt. Use prompt="Summarize:" for summaries. Uses all the text if entire_page=True and only visible text if False. Invoked with commands like "retrieve", "find in the page", or similar.
 - `env.ask_llm_to_find_element(description)` asks AI to find an GPTWebElement that matches the description. It returns None if it cannot find an element that matches the description, so you must check for that.
